==> infinity_client-0.0.58.tar.gz: infinity_client-0.0.58/README.md <==
# infinity_client
A client library for accessing ♾️ Infinity - Embedding Inference Server

## Installation 
```bash
pip install infinity_client
```

## Usage
First, create a client:

```python
from infinity_client import Client
client = Client(base_url="https://infinity.modal.michaelfeil.eu")
```

If the endpoints you're going to hit require authentication, use `AuthenticatedClient` instead:

```python
from infinity_client import AuthenticatedClient

client = AuthenticatedClient(base_url="https://infinity.modal.michaelfeil.eu", token="SuperSecretToken")
```

Now call your endpoint and use your models:

```python
from infinity_client.models import OpenAIModelInfo
from infinity_client.api.default import models, health
from infinity_client.types import Response

with client as client:
    model_info: OpenAIModelInfo = models.sync(client=client)
    # or if you need more info (e.g. status_code)
    response: Response[OpenAIModelInfo] = models.sync_detailed(client=client)
```

Or use the POST methods:

```python
from infinity_client.models import OpenAIEmbeddingInput, OpenAIEmbeddingResult
from infinity_client.api.default import classify, embeddings, embeddings_image, rerank
from infinity_client.types import Response

with client as client:
    embeds: OpenAIEmbeddingResult = embeddings.sync(client=client, body=OpenAIEmbeddingInput.from_dict({
        "input":["Hello, this is a sentence-to-embed", "Hello, my cat is cute"],
        "model": "michaelfeil/bge-small-en-v1.5",
    }))
```

Or do the same thing with an async version:

```python
from infinity_client.models import OpenAIModelInfo
from infinity_client.api.my_tag import models
from infinity_client.types import Response

async with client as client:
    model_info: OpenAIModelInfo = await models.asyncio(client=client)
    response: Response[OpenAIModelInfo] = await models.asyncio_detailed(client=client)
```


By default, when you're calling an HTTPS API it will attempt to verify that SSL is working correctly. Using certificate verification is highly recommended most of the time, but sometimes you may need to authenticate to a server (especially an internal server) using a custom certificate bundle.

```python
client = AuthenticatedClient(
    base_url="https://internal_api.example.com", 
    token="SuperSecretToken",
    verify_ssl="/path/to/certificate_bundle.pem",
)
```

You can also disable certificate validation altogether, but beware that **this is a security risk**.

```python
client = AuthenticatedClient(
    base_url="https://internal_api.example.com", 
    token="SuperSecretToken", 
    verify_ssl=False
)
```

Things to know:
1. Every path/method combo becomes a Python module with four functions:
    1. `sync`: Blocking request that returns parsed data (if successful) or `None`
    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.
    1. `asyncio`: Like `sync` but async instead of blocking
    1. `asyncio_detailed`: Like `sync_detailed` but async instead of blocking

1. All path/query params, and bodies become method arguments.
1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)
1. Any endpoint which did not have a tag will be in `infinity_client.api.default`

## Advanced customizations

There are more settings on the generated `Client` class which let you control more runtime behavior, check out the docstring on that class for more info. You can also customize the underlying `httpx.Client` or `httpx.AsyncClient` (depending on your use-case):

```python
from infinity_client import Client

def log_request(request):
    print(f"Request event hook: {request.method} {request.url} - Waiting for response")

def log_response(response):
    request = response.request
    print(f"Response event hook: {request.method} {request.url} - Status {response.status_code}")

client = Client(
    base_url="https://infinity.modal.michaelfeil.eu",
    httpx_args={"event_hooks": {"request": [log_request], "response": [log_response]}},
)

# Or get the underlying httpx client to modify directly with client.get_httpx_client() or client.get_async_httpx_client()
```

You can even set the httpx client directly, but beware that this will override any existing settings (e.g., base_url):

```python
import httpx
from infinity_client import Client

client = Client(
    base_url="https://infinity.modal.michaelfeil.eu",
)
# Note that base_url needs to be re-set, as would any shared cookies, headers, etc.
client.set_httpx_client(httpx.Client(base_url="https://infinity.modal.michaelfeil.eu", proxies="http://localhost:8030"))
```

## Building / publishing this package
This project uses [Poetry](https://python-poetry.org/) to manage dependencies  and packaging.  Here are the basics:
1. Update the metadata in pyproject.toml (e.g. authors, version)
1. If you're using a private repository, configure it with Poetry
    1. `poetry config repositories.<your-repository-name> <url-to-your-repository>`
    1. `poetry config http-basic.<your-repository-name> <username> <password>`
1. Publish the client with `poetry publish --build -r <your-repository-name>` or, if for public PyPI, just `poetry publish --build`

If you want to install this client into another project without publishing it (e.g. for development) then:
1. If that project **is using Poetry**, you can simply do `poetry add <path-to-this-client>` from that project
1. If that project is not using Poetry:
    1. Build a wheel with `poetry build -f wheel`
    1. Install that wheel from the other project `pip install <path-to-wheel>`

==> infinity_client-0.0.70.tar.gz: infinity_client-0.0.70/README.md <==
# infinity_client
A client library for accessing ♾️ Infinity - Embedding Inference Server

## Installation 
```bash
pip install infinity_client
```

## Usage
First, create a client:

```python
from infinity_client import Client
i_client = Client(base_url="https://infinity.modal.michaelfeil.eu")
```

If the endpoints you're going to hit require authentication, use `AuthenticatedClient` instead:

```python
from infinity_client import AuthenticatedClient

i_client = AuthenticatedClient(base_url="https://infinity.modal.michaelfeil.eu", token="SuperSecretToken")
```

Now call your endpoint and use your models:

```python
from infinity_client.models import OpenAIModelInfo
from infinity_client.api.default import models, health
from infinity_client.types import Response

with i_client as client:
    model_info: OpenAIModelInfo = models.sync(client=client)
    # or if you need more info (e.g. status_code)
    response: Response[OpenAIModelInfo] = models.sync_detailed(client=client)
```

Or use the POST methods:

```python
from infinity_client.models import OpenAIEmbeddingInput, OpenAIEmbeddingResult
from infinity_client.api.default import classify, embeddings, embeddings_image, rerank
from infinity_client.types import Response

with i_client as client:
    embeds: OpenAIEmbeddingResult = embeddings.sync(client=client, body=OpenAIEmbeddingInput.from_dict({
        "input": ["Hello, this is a sentence-to-embed", "Hello, my cat is cute"],
        "model": "michaelfeil/bge-small-en-v1.5",
    }))
```

Or do the same thing with an async version:

```python
from infinity_client.models import OpenAIModelInfo
from infinity_client.api.default import models
from infinity_client.types import Response

async with i_client as client:
    model_info: OpenAIModelInfo = await models.asyncio(client=client)
    response: Response[OpenAIModelInfo] = await models.asyncio_detailed(client=client)
```


By default, when you're calling an HTTPS API it will attempt to verify that SSL is working correctly. Using certificate verification is highly recommended most of the time, but sometimes you may need to authenticate to a server (especially an internal server) using a custom certificate bundle.

```python
i_client = AuthenticatedClient(
    base_url="https://internal_api.example.com",
    token="SuperSecretToken",
    verify_ssl="/path/to/certificate_bundle.pem",
)
```

You can also disable certificate validation altogether, but beware that **this is a security risk**.

```python
i_client = AuthenticatedClient(
    base_url="https://internal_api.example.com", 
    token="SuperSecretToken", 
    verify_ssl=False
)
```

Things to know:
1. Every path/method combo becomes a Python module with four functions:
    1. `sync`: Blocking request that returns parsed data (if successful) or `None`
    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.
    1. `asyncio`: Like `sync` but async instead of blocking
    1. `asyncio_detailed`: Like `sync_detailed` but async instead of blocking

1. All path/query params, and bodies become method arguments.
1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)
1. Any endpoint which did not have a tag will be in `infinity_client.api.default`

## Advanced customizations

There are more settings on the generated `Client` class which let you control more runtime behavior, check out the docstring on that class for more info. You can also customize the underlying `httpx.Client` or `httpx.AsyncClient` (depending on your use-case):

```python
from infinity_client import Client

def log_request(request):
    print(f"Request event hook: {request.method} {request.url} - Waiting for response")

def log_response(response):
    request = response.request
    print(f"Response event hook: {request.method} {request.url} - Status {response.status_code}")

i_client = Client(
    base_url="https://infinity.modal.michaelfeil.eu",
    httpx_args={"event_hooks": {"request": [log_request], "response": [log_response]}},
)

# Or get the underlying httpx client to modify directly with client.get_httpx_client() or client.get_async_httpx_client()
```

You can even set the httpx client directly, but beware that this will override any existing settings (e.g., base_url):

```python
import httpx
from infinity_client import Client

i_client = Client(
    base_url="https://infinity.modal.michaelfeil.eu",
)
# Note that base_url needs to be re-set, as would any shared cookies, headers, etc.
i_client.set_httpx_client(httpx.Client(base_url="https://infinity.modal.michaelfeil.eu", proxies="http://localhost:8030"))
```

## Building / publishing this package
This project uses [Poetry](https://python-poetry.org/) to manage dependencies  and packaging.  Here are the basics:
1. Update the metadata in pyproject.toml (e.g. authors, version)
1. If you're using a private repository, configure it with Poetry
    1. `poetry config repositories.<your-repository-name> <url-to-your-repository>`
    1. `poetry config http-basic.<your-repository-name> <username> <password>`
1. Publish the client with `poetry publish --build -r <your-repository-name>` or, if for public PyPI, just `poetry publish --build`

If you want to install this client into another project without publishing it (e.g. for development) then:
1. If that project **is using Poetry**, you can simply do `poetry add <path-to-this-client>` from that project
1. If that project is not using Poetry:
    1. Build a wheel with `poetry build -f wheel`
    1. Install that wheel from the other project `pip install <path-to-wheel>`
